==> jc-1.4.0.tar.gz: java/lang/NumberFormatException.h <==
// public class java.lang.NumberFormatException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class a9fd317e4e09506e java_lang_NumberFormatException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_lang_NumberFormatException_H_
#define _JC_java_lang_NumberFormatException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NumberFormatException$sub_refs	_jc_java_lang_NumberFormatException$sub_refs;
typedef struct _jc_java_lang_NumberFormatException$sub_nonrefs	_jc_java_lang_NumberFormatException$sub_nonrefs;
typedef struct _jc_java_lang_NumberFormatException$refs	_jc_java_lang_NumberFormatException$refs;
typedef struct _jc_java_lang_NumberFormatException$nonrefs	_jc_java_lang_NumberFormatException$nonrefs;
typedef struct _jc_java_lang_NumberFormatException$object	_jc_java_lang_NumberFormatException$object;

typedef struct _jc_java_lang_NumberFormatException$fields_struct	_jc_java_lang_NumberFormatException$fields_struct;
typedef const struct _jc_java_lang_NumberFormatException$vmethods	_jc_java_lang_NumberFormatException$vmethods;
typedef const struct _jc_java_lang_NumberFormatException$vtable	_jc_java_lang_NumberFormatException$vtable;
typedef const struct _jc_java_lang_NumberFormatException$vtype	_jc_java_lang_NumberFormatException$vtype;

// Class fields structure
struct _jc_java_lang_NumberFormatException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NumberFormatException$fields_struct _jc_java_lang_NumberFormatException$class_fields;

// Constructors
extern void _jc_java_lang_NumberFormatException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NumberFormatException$object *);
extern void _jc_java_lang_NumberFormatException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NumberFormatException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_NumberFormatException$vmethods {
};

// Vtable
struct _jc_java_lang_NumberFormatException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_lang_NumberFormatException$vmethods	java_lang_NumberFormatException;
};

// Vtype
struct _jc_java_lang_NumberFormatException$vtype {
	_jc_type			type;
	_jc_java_lang_NumberFormatException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NumberFormatException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NumberFormatException$refs {
    _jc_java_lang_NumberFormatException$sub_refs	java_lang_NumberFormatException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NumberFormatException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NumberFormatException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_lang_NumberFormatException$sub_nonrefs	java_lang_NumberFormatException;
};

// Object instance structure
struct _jc_java_lang_NumberFormatException$object {
	_jc_java_lang_NumberFormatException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NumberFormatException$vtype	*vtype;
	_jc_java_lang_NumberFormatException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NumberFormatException$vtype _jc_java_lang_NumberFormatException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NumberFormatException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NumberFormatException$class_object;

#endif	/* _JC_java_lang_NumberFormatException_H_ */

==> jc-1.4.6.tar.gz: java/lang/NumberFormatException.h <==
// public class java.lang.NumberFormatException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class a9fd317e4e09506e java_lang_NumberFormatException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_lang_NumberFormatException_H_
#define _JC_java_lang_NumberFormatException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NumberFormatException$sub_refs	_jc_java_lang_NumberFormatException$sub_refs;
typedef struct _jc_java_lang_NumberFormatException$sub_nonrefs	_jc_java_lang_NumberFormatException$sub_nonrefs;
typedef struct _jc_java_lang_NumberFormatException$refs	_jc_java_lang_NumberFormatException$refs;
typedef struct _jc_java_lang_NumberFormatException$nonrefs	_jc_java_lang_NumberFormatException$nonrefs;
typedef struct _jc_java_lang_NumberFormatException$object	_jc_java_lang_NumberFormatException$object;

typedef struct _jc_java_lang_NumberFormatException$fields_struct	_jc_java_lang_NumberFormatException$fields_struct;
typedef const struct _jc_java_lang_NumberFormatException$vmethods	_jc_java_lang_NumberFormatException$vmethods;
typedef const struct _jc_java_lang_NumberFormatException$vtable	_jc_java_lang_NumberFormatException$vtable;
typedef const struct _jc_java_lang_NumberFormatException$vtype	_jc_java_lang_NumberFormatException$vtype;

// Class fields structure
struct _jc_java_lang_NumberFormatException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NumberFormatException$fields_struct _jc_java_lang_NumberFormatException$class_fields;

// Constructors
extern void _jc_java_lang_NumberFormatException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NumberFormatException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_NumberFormatException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NumberFormatException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_NumberFormatException$vmethods {
};

// Vtable
struct _jc_java_lang_NumberFormatException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_lang_NumberFormatException$vmethods	java_lang_NumberFormatException;
};

// Vtype
struct _jc_java_lang_NumberFormatException$vtype {
	_jc_type			type;
	_jc_java_lang_NumberFormatException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NumberFormatException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NumberFormatException$refs {
    _jc_java_lang_NumberFormatException$sub_refs	java_lang_NumberFormatException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NumberFormatException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NumberFormatException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_lang_NumberFormatException$sub_nonrefs	java_lang_NumberFormatException;
};

// Object instance structure
struct _jc_java_lang_NumberFormatException$object {
	_jc_java_lang_NumberFormatException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NumberFormatException$vtype	*vtype;
	_jc_java_lang_NumberFormatException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NumberFormatException$vtype _jc_java_lang_NumberFormatException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NumberFormatException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NumberFormatException$class_object;

#endif	/* _JC_java_lang_NumberFormatException_H_ */
